NStrokeStyle enum
Values
- solid → const NStrokeStyle
-
const NStrokeStyle('solid') - shortdash → const NStrokeStyle
-
const NStrokeStyle('shortdash') - shortdot → const NStrokeStyle
-
const NStrokeStyle('shortdot') - shortdashdot → const NStrokeStyle
-
const NStrokeStyle('shortdashdot') - shortdashdotdot → const NStrokeStyle
-
const NStrokeStyle('shortdashdotdot') - dot → const NStrokeStyle
-
const NStrokeStyle('dot') - dash → const NStrokeStyle
-
const NStrokeStyle('dash') - longdash → const NStrokeStyle
-
const NStrokeStyle('longdash') - dashdot → const NStrokeStyle
-
const NStrokeStyle('dashdot') - longdashdot → const NStrokeStyle
-
const NStrokeStyle('longdashdot') - longdashdotdot → const NStrokeStyle
-
const NStrokeStyle('longdashdotdot')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NStrokeStyle> - A constant List of the values in this enum, in order of their declaration.